@@ -51,7 +51,6 @@ class AudioGenreStorage(Device):
         f.mimetype = f.DIRECTORY
         f.icon = theme.mb_folder_genre.get_path()
         f.folder_flags = f.ITEMS_ENQUEUEABLE | \
-                         f.ITEMS_SKIPPABLE | \
                          f.ITEMS_COMPACT
         return f
 
@@ -75,7 +74,6 @@ class AudioGenreStorage(Device):
             # root folder
             f = File(self)
             f.is_local = True
-            f.can_skip = True
             f.path = "/"
             f.mimetype = f.DEVICE_ROOT
             f.resource = ""
