@@ -14,6 +14,17 @@ class ButtonItem(Item):
         Item.__init__(self)
         
         
+    def is_button(self):
+    
+        return True
+        
+    
+    def set_text(self, text):
+    
+        self.__label = text
+        self._invalidate_cached_pixmap()
+        
+        
     def render_at(self, cnv, x, y):
     
         w, h = self.get_size()
